## What is this project?
This is a Weather Forecast Package (Python Library) made while
learning Python programming. It uses openweather.org API
to get weather data around the globe with the main idea being
sharing it with other developers so anyone 
can have a handy weather forecast lib. 
Also, it's good to learn how to upload packages on PyPI.